server_client_20141231_085104

### config2 : test_client_timeout

Result | Function execution time | Total execution time
--- | --- | ---
Failed | 60.7626769543 sec | 62.44592309 sec

Error message: Did not properly handle client timeout

Naarad report

### Metrics

#### server1-perf

Submetric | max | mean | min | p50 | p75 | p90 | p95 | p99 | std
--- | --- | --- | --- | --- | --- | --- | --- | --- | ---
latency | 572.45 | 0.7 | 0.073 | 0.098 | 0.12 | 0.15 | 0.17 | 0.46 | 18.08
qps | 435.00 | 333.67 | 234.00 | 332.00 | 383.50 | 414.40 | 424.70 | 432.94 | 82.07

#### client1-perf

Submetric | max | mean | min | p50 | p75 | p90 | p95 | p99 | std
--- | --- | --- | --- | --- | --- | --- | --- | --- | ---
latency | 2341.21 | 2341.21 | 2341.21 | 2341.21 | 2341.21 | 2341.21 | 2341.21 | 2341.21 | 0.0
qps | 1.0 | 1.0 | 1.0 | 1.0 | 1.0 | 1.0 | 1.0 | 1.0 | 0.0

### SLAs

metric | submetric | sla rule | value
--- | --- | --- | ---
server1-perf | qps | mean lt 7.0 | 333.666666667
server1-perf | latency | p50 lt 0.3 | 0.098
server1-perf | latency | mean lt 0.33 | 0.698632367632
server2-perf | qps | mean lt 7.0 | None
server2-perf | latency | p50 lt 0.3 | None
server2-perf | latency | mean lt 0.33 | None
server3-perf | qps | mean lt 7.0 | None
server3-perf | latency | p50 lt 0.3 | None
server3-perf | latency | mean lt 0.33 | None
client1-perf | qps | mean lt 2.0 | 1.0
client1-perf | latency | p50 lt 22.0 | 2341.21
client1-perf | latency | mean lt 35.0 | 2341.21
client2-perf | qps | mean lt 2.0 | None
client2-perf | latency | p50 lt 22.0 | None
client2-perf | latency | mean lt 35.0 | None